@@ -25,7 +25,15 @@ from __future__ import annotations
 
 import typing
 from sigparse._sigparse import sigparse, Parameter
-from sigparse._classparse import classparse
+from sigparse._classparse import classparse, ClassVar
 from sigparse._pep604 import global_PEP604
+from sigparse import utils
 
-__all__: typing.Sequence[str] = ("classparse", "sigparse", "Parameter", "global_PEP604")
+__all__: typing.Sequence[str] = (
+    "classparse",
+    "sigparse",
+    "Parameter",
+    "ClassVar",
+    "global_PEP604",
+    "utils",
+)
